pub struct SelectRecvError;Expand description
An error returned from the Select::recv method.
This error occurs when the selection case doesn’t receive a message from the channel. Note that cases enumerated in a selection loop are sometimes simply skipped, so they might fail even if the channel is currently not empty.